=====
Usage
=====

To use PIP Chill in a project::


```
>>> import pip_chill
>>> pip_chill.chill()  #doctest: +ELLIPSIS
([<pip_chill.pip_chill.Distribution instance "...">, <pip_chill.pip_chill.Distribution instance "...">, ...

```
